# Midi generator using genetic algorithms
[![Upload Python Package](https://github.com/speedypleath/midi_generator/actions/workflows/python-publish.yml/badge.svg)](https://github.com/speedypleath/midi_generator/actions/workflows/python-publish.yml)
